# -*- coding: utf-8 -*-
# Description:
# Parser test for Acunetix
#
# Authors:
# Benoît Allard <benoit.allard@greenbone.net>
#
# Copyright:
# Copyright (C) 2015 Greenbone Networks GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import unittest

from ospd_acunetix.parser import ReportItem

import xml.etree.ElementTree as ET

class testReportItem(unittest.TestCase):

    def testInit(self):
        item = ReportItem(ET.fromstring("""
<ReportItem id="1" color="orange">
       <Name><![CDATA[Insecure transition from HTTP to HTTPS in form post]]></Name>
       <ModuleName><![CDATA[Crawler]]></ModuleName>
       <Details><![CDATA[Form name: <font color="dark">&quot;frm&quot;</font><br/>Form action: <font color="dark">&quot;https://www.salesforce.com/servlet/servlet.WebToLead?encoding=UTF-8&quot;</font><br/>]]></Details>
       <Affects><![CDATA[/vormerken.html]]></Affects>
       <Parameter><![CDATA[]]></Parameter>
       <AOP_SourceFile><![CDATA[]]></AOP_SourceFile>
       <AOP_SourceLine>0</AOP_SourceLine>
       <AOP_Additional><![CDATA[]]></AOP_Additional>
       <IsFalsePositive><![CDATA[False]]></IsFalsePositive>
       <Severity><![CDATA[medium]]></Severity>
       <Type><![CDATA[Configuration]]></Type>
       <Impact><![CDATA[Possible information disclosure.]]></Impact>
       <Description><![CDATA[This form is served from an insecure page (http) page. This page could be hijacked using a Man-in-the-middle attack and an attacker can replace the form target.]]></Description>
       <DetailedInformation><![CDATA[]]></DetailedInformation>
       <Recommendation><![CDATA[The form should be served from a secure (https) page.]]></Recommendation>
       <TechnicalDetails>
        <Request><![CDATA[GET /vormerken.html HTTP/1.1
Pragma: no-cache
Cache-Control: no-cache
Referer: http://www.example.com/
Acunetix-Aspect: enabled
Acunetix-Aspect-Password: 082119f75623eb7abd7bf357698ff66c
Acunetix-Aspect-Queries: filelist;aspectalerts
Host: www.example.com
Connection: Keep-alive
Accept-Encoding: gzip,deflate
User-Agent: Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.21 (KHTML, like Gecko) Chrome/41.0.2228.0 Safari/537.21
Acunetix-Product: WVS/9.0 (Acunetix Web Vulnerability Scanner - NORMAL)
Acunetix-Scanning-agreement: Third Party Scanning PROHIBITED
Acunetix-User-agreement: http://www.acunetix.com/wvs/disc.htm
Accept: */*

]]></Request>
        <Response><![CDATA[HTTP/1.1 200 OK
Server: nginx
Date: Wed, 15 Jul 2015 09:45:34 GMT
Content-Type: text/html
Last-Modified: Wed, 15 Jul 2015 09:13:44 GMT
Connection: keep-alive
Keep-Alive: timeout=20
ETag: W/&quot;55a62448-2616&quot;
Original-Content-Encoding: gzip
Content-Length: 9750
]]></Response>
       </TechnicalDetails>
       <CWE id="200"><![CDATA[CWE-200]]></CWE>
      <CVEList>
       <CVE>
         <Id><![CDATA[CVE-2014-0133]]></Id>
       </CVE>
      </CVEList>
       <CVSS>
          <Descriptor><![CDATA[AV:N/AC:M/Au:N/C:N/I:N/A:N]]></Descriptor>
          <Score><![CDATA[0.0]]></Score>
          <AV><![CDATA[Network]]></AV>
          <AVdesc><![CDATA[A vulnerability exploitable with network access means the vulnerable software is bound to the network stack and the attacker does not require local network access or local access.]]></AVdesc>
          <AC><![CDATA[Medium]]></AC>
          <ACdesc><![CDATA[The access conditions are somewhat specialized.]]></ACdesc>
          <Au><![CDATA[None]]></Au>
          <Audesc><![CDATA[Authentication is not required to exploit the vulnerability.]]></Audesc>
          <C><![CDATA[None]]></C>
          <Cdesc><![CDATA[There is no impact to the confidentiality of the system.]]></Cdesc>
          <I><![CDATA[None]]></I>
          <Idesc><![CDATA[There is no impact to the integrity of the system.]]></Idesc>
          <A><![CDATA[None]]></A>
          <Adesc><![CDATA[There is no impact to the availability of the system.]]></Adesc>
          <E><![CDATA[]]></E>
          <Edesc><![CDATA[]]></Edesc>
          <RL><![CDATA[]]></RL>
          <RLdesc><![CDATA[]]></RLdesc>
          <RC><![CDATA[]]></RC>
          <RCdesc><![CDATA[]]></RCdesc>
       </CVSS>
       <References>
        <Reference>
          <Database><![CDATA[The X-Frame-Options response header]]></Database>
          <URL><![CDATA[https://developer.mozilla.org/en-US/docs/HTTP/X-Frame-Options]]></URL>
        </Reference>
        <Reference>
          <Database><![CDATA[Clickjacking]]></Database>
          <URL><![CDATA[http://en.wikipedia.org/wiki/Clickjacking]]></URL>
        </Reference>
        <Reference>
          <Database><![CDATA[Original Clickjacking paper]]></Database>
          <URL><![CDATA[http://www.sectheory.com/clickjacking.htm]]></URL>
        </Reference>
        <Reference>
          <Database><![CDATA[Defending with Content Security Policy frame-ancestors directive]]></Database>
          <URL><![CDATA[https://www.owasp.org/index.php/Clickjacking_Defense_Cheat_Sheet#Defending_with_Content_Security_Policy_frame-ancestors_directive]]></URL>
        </Reference>
        <Reference>
          <Database><![CDATA[Frame Buster Buster]]></Database>
          <URL><![CDATA[http://stackoverflow.com/questions/958997/frame-buster-buster-buster-code-needed]]></URL>
        </Reference>
        <Reference>
          <Database><![CDATA[Clickjacking Protection for Java EE]]></Database>
          <URL><![CDATA[https://www.owasp.org/index.php/Clickjacking_Protection_for_Java_EE]]></URL>
        </Reference>
       </References>
      </ReportItem>"""))
        self.assertEqual(item.name, "Insecure transition from HTTP to HTTPS in form post")
        self.assertEqual(item.affects, "/vormerken.html")
        self.assertEqual(item.severity, "medium")
        self.assertEqual(item.type, "Configuration")
        self.assertEqual(item.impact, "Possible information disclosure.")
        self.assertEqual(item.description, "This form is served from an insecure page (http) page. This page could be hijacked using a Man-in-the-middle attack and an attacker can replace the form target.")
        self.assertEqual(item.recommendation, "The form should be served from a secure (https) page.")
        self.assertEqual(item.CWE, 200)
        self.assertEqual(item.CVEs, ['CVE-2014-0133'])
        self.assertEqual(item.CVSS, "AV:N/AC:M/Au:N/C:N/I:N/A:N")
        self.assertEqual(item.CVSSScore, 0.)
        self.assertEqual(len(item.references), 6)
